==> openshift-model-operatorhub-5.7.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class InstallPlanBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanBuilder>{
  public InstallPlanBuilder() {
    this(false);
  }
  public InstallPlanBuilder(java.lang.Boolean validationEnabled) {
    this(new InstallPlan(), validationEnabled);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent) {
    this(fluent, false);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new InstallPlan(), validationEnabled);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan instance) {
    this(fluent, instance, false);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan instance) {
    this(instance,false);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan build() {
    InstallPlan buildable = new InstallPlan(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    InstallPlanBuilder that = (InstallPlanBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class InstallPlanBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanBuilder>{
  public InstallPlanBuilder() {
    this(false);
  }
  public InstallPlanBuilder(java.lang.Boolean validationEnabled) {
    this(new InstallPlan(), validationEnabled);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent) {
    this(fluent, false);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new InstallPlan(), validationEnabled);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan instance) {
    this(fluent, instance, false);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan instance) {
    this(instance,false);
  }
  public InstallPlanBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan build() {
    InstallPlan buildable = new InstallPlan(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    InstallPlanBuilder that = (InstallPlanBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
